// *******************************************************************
// Document.h
// *******************************************************************
//
//  DESCRIPTION: API for Document class. Used to manipulate a
//                         given document.
//  NOTE:             This program makes use of strings.
//
/***************************************************************************
 *   Copyright (C) 2003 by drs. Eric D. Schabell                           *
 *   erics@cs.kun.nl                                                       *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 ***************************************************************************/


//--------------------------------------------------------------------
//conditional compilation
//--------------------------------------------------------------------
#ifndef _DOCUMENT_H_
#define _DOCUMENT_H_

//--------------------------------------------------------------------
//#includes
//--------------------------------------------------------------------
#include <string>

using namespace std;

class Document
{
public:

    //--------------------------------------------------------------------
    //Purpose:           default constructor.
    //Preconditions:    none.
    //Postconditions:  a Document object is instantiated and all
    //                       attributes are zeroed.
    //Arguments:       none.
    //Returns:           Document.
    //Called Funcs:    none.
    //--------------------------------------------------------------------
    Document();

    //--------------------------------------------------------------------
    //Purpose:            constructor with url and conversion given..
    //Preconditions:    must supply a string document url and a
    //                        string conversion routine.
    //Postconditions:  a Document object is instantiated with a
    //                       document url, file name and conversion
    //                       routine defined. File location and Conversion
    //                       location are zeroed.
    //Arguments:       string doc_url, string routine.
    //Returns:           Document.
    //Called Funcs:    setDocumentFile(), setDocumentConversion().
    //--------------------------------------------------------------------
    Document( string doc_url, string routine );

    //--------------------------------------------------------------------
    //Purpose:            default destructor.
    //Preconditions:    Document object.
    //Postconditions:  Document object destroyed.
    //Arguments:       none.
    //Returns:           0
    //Called Funcs:    none.
    //--------------------------------------------------------------------
    ~Document();

    //--------------------------------------------------------------------
    //Purpose:            obtain the documents complete url.
    //Preconditions:    Docuemnt object exists.
    //Postconditions:  returns url attribute.
    //Arguments:       none.
    //Returns:           string.
    //Called Funcs:    none.
    //--------------------------------------------------------------------
    string getDocumentUrl();

    //--------------------------------------------------------------------
    //Purpose:            Return the file name if instantiated, otherwise
    //                        returns the url attribute.
    //Preconditions:    Docuemnt object created.
    //Postconditions:  success = returns instantiated file attribute.
    //                       failure    = returns url if file has not been instantiated,
    //                                      which signals a problem with the
    //                                      document construction.
    //Arguments:       none.
    //Returns:           string
    //Called Funcs:    none.
    //--------------------------------------------------------------------
    string getDocumentFile();

    //--------------------------------------------------------------------
    //Purpose:            Return the conversion routine attribute.
    //Preconditions:    Docuemnt object created.
    //Postconditions:  returns instantiated file attribute.
    //Arguments:       none.
    //Returns:           string
    //Called Funcs:    none.
    //--------------------------------------------------------------------
    string getDocumentConversion();

    //--------------------------------------------------------------------
    //Purpose:            Return the conLocation attribute.
    //Preconditions:    Docuemnt object created.
    //Postconditions:  returns conLocation attribute.
    //Arguments:       none.
    //Returns:           string
    //Called Funcs:    none.
    //--------------------------------------------------------------------
    string getConversionLocation();

    //--------------------------------------------------------------------
    //Purpose:            Return the docuemnt file location.
    //Preconditions:    Docuemnt object created.
    //Postconditions:  returns fileLocation attribute.
    //Arguments:       none.
    //Returns:           string
    //Called Funcs:    none.
    //--------------------------------------------------------------------
    string getFileLocation();

    //--------------------------------------------------------------------
    //Purpose:            Sets the file location to given location.
    //Preconditions:    Docuemnt object created, location provided.
    //Postconditions:  fileLocation attribute is set with given file
    //                       location.
    //Arguments:       string file_location.
    //Returns:           0.
    //Called Funcs:    none.
    //--------------------------------------------------------------------
    void setFileLocation( string file_location );

    //--------------------------------------------------------------------
    //Purpose:            Sets the converted files location to given location.
    //Preconditions:    Docuemnt object created, location provided.
    //Postconditions:  conLocation attribute is set with given file
    //                       location.
    //Arguments:       string conversion_location.
    //Returns:           0.
    //Called Funcs:    none.
    //--------------------------------------------------------------------
    void setConversionLocation( string conversion_location );

private:
    string url;					// url to location of document.
    string file;					// document basename.
    string conversion;		// conversion being requested on this docuement.
    string conLocation;	// location of converted docuement (url or local file system)
    string fileLocation;	// location of basename (local file system).

    //--------------------------------------------------------------------
    //Purpose:            Determine and set the file name by basnaming
    //                        the url attribute.
    //Preconditions:    Docuemnt object created.
    //Postconditions:  success = a set file attribute.
    //                       failure    = returns error
    //Arguments:       none.
    //Returns:           0.
    //Called Funcs:    basename().
    //--------------------------------------------------------------------
    void setDocumentFile();

    //--------------------------------------------------------------------
    //Purpose:           Instantiates the conversion attribute with the
    //                       given convertion routine.
    //Preconditions:   Docuemnt object created, convertion routine
    //                       provided. .
    //Postconditions:  instantiated conversion attribute.
    //Arguments:       string convertion_request..
    //Returns:           0.
    //Called Funcs:    none.
    //--------------------------------------------------------------------
    void setDocumentConversion( string conversion_request );
};

#endif /* _DOCUMENT_H_  */
